@@ -167,6 +167,16 @@ impl<R: Requester> Provider<R> for SearchChClient<R> {
         Ok(response.into_iter().map(Into::into).collect())
     }
 
+    async fn station_board(
+        &self,
+        _place: rcore::Place,
+        _kind: rcore::StationBoardKind,
+        _opts: rcore::StationBoardOptions,
+    ) -> Result<rcore::StationBoardResponse, rcore::Error<<R as Requester>::Error, Self::Error>>
+    {
+        Err(rcore::Error::NotImplemented)
+    }
+
     // Note: search.ch does not support any of those options.
     // This method is not guaranteed to find the same journey. But I think this is the best we can do as search.ch does not provide a refresh-API.
     async fn refresh_journey(
